@@ -104,7 +104,7 @@ class LogLimits:
     This class does not enforce any limits itself. It only provides a way to read limits from env,
     default values and from user provided arguments.
 
-    All limit arguments must be either a non-negative integer, ``None`` or ``LogLimits.UNSET``.
+    All limit arguments must be either a non-negative integer or ``None``.
 
     - All limit arguments are optional.
     - If a limit argument is not set, the class will try to read its value from the corresponding
@@ -126,8 +126,6 @@ class LogLimits:
             the specified length will be truncated.
     """
 
-    UNSET = -1
-
     def __init__(
         self,
         max_attributes: int | None = None,
@@ -156,9 +154,6 @@ class LogLimits:
     def _from_env_if_absent(
         cls, value: int | None, env_var: str, default: int | None = None
     ) -> int | None:
-        if value == cls.UNSET:
-            return None
-
         err_msg = "{} must be a non-negative integer but got {}"
 
         # if no value is provided for the limit, try to load it from env
@@ -181,12 +176,6 @@ class LogLimits:
         return value
 
 
-_UnsetLogLimits = LogLimits(
-    max_attributes=LogLimits.UNSET,
-    max_attribute_length=LogLimits.UNSET,
-)
-
-
 class LogRecord(APILogRecord):
     """A LogRecord instance represents an event being logged.
 
@@ -206,7 +195,7 @@ class LogRecord(APILogRecord):
         body: AnyValue | None = None,
         resource: Resource | None = None,
         attributes: _ExtendedAttributes | None = None,
-        limits: LogLimits | None = _UnsetLogLimits,
+        limits: LogLimits | None = None,
         event_name: str | None = None,
     ): ...
 
@@ -226,7 +215,7 @@ class LogRecord(APILogRecord):
         body: AnyValue | None = None,
         resource: Resource | None = None,
         attributes: _ExtendedAttributes | None = None,
-        limits: LogLimits | None = _UnsetLogLimits,
+        limits: LogLimits | None = None,
     ): ...
 
     def __init__(  # pylint:disable=too-many-locals
@@ -242,7 +231,7 @@ class LogRecord(APILogRecord):
         body: AnyValue | None = None,
         resource: Resource | None = None,
         attributes: _ExtendedAttributes | None = None,
-        limits: LogLimits | None = _UnsetLogLimits,
+        limits: LogLimits | None = None,
         event_name: str | None = None,
     ):
         if trace_id or span_id or trace_flags:
@@ -258,6 +247,10 @@ class LogRecord(APILogRecord):
         span = get_current_span(context)
         span_context = span.get_span_context()
 
+        # Use default LogLimits if none provided
+        if limits is None:
+            limits = LogLimits()
+
         super().__init__(
             **{
                 "timestamp": timestamp,
@@ -306,7 +299,9 @@ class LogRecord(APILogRecord):
                     dict(self.attributes) if bool(self.attributes) else None
                 ),
                 "dropped_attributes": self.dropped_attributes,
-                "timestamp": ns_to_iso_str(self.timestamp),
+                "timestamp": ns_to_iso_str(self.timestamp)
+                if self.timestamp is not None
+                else None,
                 "observed_timestamp": ns_to_iso_str(self.observed_timestamp),
                 "trace_id": (
                     f"0x{format_trace_id(self.trace_id)}"
@@ -335,6 +330,25 @@ class LogRecord(APILogRecord):
             return attributes.dropped
         return 0
 
+    @classmethod
+    def _from_api_log_record(
+        cls, *, record: APILogRecord, resource: Resource
+    ) -> LogRecord:
+        return cls(
+            timestamp=record.timestamp,
+            observed_timestamp=record.observed_timestamp,
+            context=record.context,
+            trace_id=record.trace_id,
+            span_id=record.span_id,
+            trace_flags=record.trace_flags,
+            severity_text=record.severity_text,
+            severity_number=record.severity_number,
+            body=record.body,
+            attributes=record.attributes,
+            event_name=record.event_name,
+            resource=resource,
+        )
+
 
 class LogData:
     """Readable LogRecord data plus associated InstrumentationLibrary."""
@@ -678,10 +692,15 @@ class Logger(APILogger):
     def resource(self):
         return self._resource
 
-    def emit(self, record: LogRecord):
+    def emit(self, record: APILogRecord):
         """Emits the :class:`LogData` by associating :class:`LogRecord`
         and instrumentation info.
         """
+        if not isinstance(record, LogRecord):
+            # pylint:disable=protected-access
+            record = LogRecord._from_api_log_record(
+                record=record, resource=self._resource
+            )
         log_data = LogData(record, self._instrumentation_scope)
         self._multi_log_record_processor.on_emit(log_data)
 
